@@ -1,4 +1,5 @@
-/* gweather-xml.h 
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+/* gweather-xml.h
  *
  * Copyright (C) 2004 Gareth Owen
  *
@@ -13,8 +14,8 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see
+ * <http://www.gnu.org/licenses/>.
  */
 
 #ifndef __GWEATHER_XML_H__
@@ -28,8 +29,9 @@ enum
     GWEATHER_XML_COL_LOC = 0,
     GWEATHER_XML_COL_POINTER,
     GWEATHER_XML_NUM_COLUMNS
-}; 
+};
 
-GtkTreeModel *gweather_xml_load_locations( void );
+GtkTreeModel *gweather_xml_load_locations (void);
+void          gweather_xml_free_locations (GtkTreeModel *locations);
 
 #endif /* __GWEATHER_XML_H__ */
